@@ -178,7 +178,7 @@ public class FolderCopyTask implements CopyUserTaskService {
                 if (!ignoreFolder(id)) {
                     originFolders.put(I(id), folder.clone());
                 }
-            } catch (final CloneNotSupportedException e) {
+            } catch (CloneNotSupportedException e) {
                 throw UserCopyExceptionCodes.UNKNOWN_PROBLEM.create(e);
             }
         }
@@ -241,7 +241,7 @@ public class FolderCopyTask implements CopyUserTaskService {
                 final FolderObject folder = buildFolderFromResultSet(rs);
                 folderMap.put(I(folder.getObjectID()), new FolderEqualsWrapper(folder, "orig"));
             }
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
             Databases.closeSQLStuff(rs, stmt);
@@ -366,7 +366,7 @@ public class FolderCopyTask implements CopyUserTaskService {
             }
 
             stmt.executeBatch();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
             Databases.closeSQLStuff(stmt);
@@ -394,9 +394,9 @@ public class FolderCopyTask implements CopyUserTaskService {
                     exchangeIds(folderTree, folder, cid, uid, con, newId, idMapping);
                 }
             }
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
-        } catch (final CloneNotSupportedException e) {
+        } catch (CloneNotSupportedException e) {
             throw UserCopyExceptionCodes.UNKNOWN_PROBLEM.create(e);
         }
     }
@@ -441,7 +441,7 @@ public class FolderCopyTask implements CopyUserTaskService {
             }
 
             stmt.executeBatch();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
             Databases.closeSQLStuff(stmt);
@@ -475,7 +475,7 @@ public class FolderCopyTask implements CopyUserTaskService {
 
                 folderList.add(folder);
             }
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
             Databases.closeSQLStuff(rs, stmt);
@@ -508,7 +508,7 @@ public class FolderCopyTask implements CopyUserTaskService {
                     if (newParentId != null) {
                         parentId = newParentId;
                     }
-                } catch (final NumberFormatException e) {
+                } catch (NumberFormatException e) {
                     // do nothing
                 }
 
@@ -548,7 +548,7 @@ public class FolderCopyTask implements CopyUserTaskService {
             }
 
             stmt.executeBatch();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw UserCopyExceptionCodes.SQL_PROBLEM.create(e);
         } finally {
             Databases.closeSQLStuff(stmt);
